/**
 * JavaScript for loading more JavaScripts with AJAX
 * --------------------------------------------------------------------
 * Copyright (c) 2003 - 2009 by Roland Haeder
 * Copyright (c) 2009 - 2013 by Mailer Developer Team
 * For more information visit: http://mxchange.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */

// Loaded scripts counter
var resourceCounter = 0;

// This array holds a copy of resources which shall be loaded
var loadResources = new Array();

// Waiting for resources being loaded
function loadScriptsLocked () {
	// Has all been loaded?
	if (resourceCounter == loadResources.length) {
		// Then release ready()
		$.holdReady(false);
	} else {
		// Recursive call again
		window.setTimeout('loadScriptsLocked()', 100);
	}
}

// Loads more JavaScript resources
function loadScripts (resources) {
	// Abort here if resources is not defined
	if (resources == undefined) {
		// This is really bad ...
		throw new 'loadScripts() called with no resources (JavaScript files) to load!';
	} // END - if

	// Make ready() as holded
	$.holdReady(true);

	// Transfer all resources to global array
	loadResources = resources;

	// Begin the loop for all JavaScript files
	for (var i = 0; i < resources.length; i++) {
		// Is the script set?
		if (resources[i] == undefined) {
			// Array element is missing, which means someone mades a boo boo ...
			throw new ('resources[' + i + '] not set. Please fix your array.');
		} // END - if

		// Load next script
		$.getScript(resources[i], function (data, textStatus) {
			// Did something bad happen?
			if (textStatus != 'success') {
				// Throw an exception here
				throw new 'Cannot load script ' + resources[i] +  ' with status ' + textStatus + '!';
			} // END - if

			// Count it as loaded
			resourceCounter++;
		});

		// Wait here a little
		$('body').delay(100);
	} // END - for

	// Wait until all scripts are loaded (asynchronously)
	loadScriptsLocked();

	// All loaded
	return true;
}
